auth0_config: Parse _auth0.yml file.

View source: R/auth0.R

auth0_configR Documentation

Parse ⁠_auth0.yml⁠ file.

Description

Validates and creates a list of useful information from the ⁠_auth0.yml⁠ file.

Usage

auth0_config(config_file)

Arguments

config_file

path to the ⁠_auth0.yml⁠ file. If not informed, will try to find the file using auth0_find_config_file.

Value

List containing all the information from the ⁠_auth0.yml⁠ file.


auth0 documentation built on April 14, 2026, 1:07 a.m.