shinyAppAuth0: Create a Shiny app object with Auth0 Authentication

View source: R/shiny.R

shinyAppAuth0R Documentation

Create a Shiny app object with Auth0 Authentication

Description

This function modifies ui and server objects to run using Auth0 authentication.

Usage

shinyAppAuth0(
  ui,
  server,
  config_file = NULL,
  remove_callback_params = TRUE,
  ...
)

Arguments

ui

an ordinary UI object to create shiny apps.

server

an ordinary server object to create shiny apps.

config_file

path to YAML configuration file.

remove_callback_params

whether to remove the code and state query parameters from the URL after successful authentication. Defaults to TRUE.

...

Other arguments passed on to shiny::shinyApp().

Details

You can also use a diferent configuration file by setting the auth0_config_file option with: options(auth0_config_file = "path/to/file.yaml").

Disable auth0 while developing apps

Sometimes, using auth0 to develop and test apps can be frustrating, because every time the app is started, auth0 requires the user to log-in. To avoid this problem, one can run options(auth0_disable = TRUE) to disable auth0 temporarily.


auth0 documentation built on April 14, 2026, 1:07 a.m.