ui-server: Modifies ui/server objects to authenticate using Auth0.

ui-serverR Documentation

Modifies ui/server objects to authenticate using Auth0.

Description

These functions can be used in a ui.R/server.R framework, modifying the shiny objects to authenticate using Auth0 service with no pain.

Usage

auth0_ui(ui, info)

auth0_server(server, info, remove_callback_params = TRUE)

Arguments

ui

shiny.tag.list object to generate the user interface.

info

object returned from auth0_info. If not informed, will try to find the ⁠_auth0.yml⁠ and create it automatically.

server

the shiny server function.

remove_callback_params

whether to remove the code and state query.

See Also

auth0_info.

Examples


# first, create the yml file using use_auth0() function

if (interactive()) {

  # ui.R file
  library(shiny)
  library(auth0)
  auth0_ui(fluidPage(logoutButton()))

  # server.R file
  library(auth0)
  auth0_server(function(input, output, session) {})

  # console
  options(shiny.port = 8080)
  shiny::runApp()
}



auth0 documentation built on April 14, 2026, 1:07 a.m.