This function modifies ui and server objects to run using Auth0 authentication.
shinyAppAuth0(
ui,
server,
config_file = NULL,
remove_callback_params = TRUE,
...
)an ordinary UI object to create shiny apps.
an ordinary server object to create shiny apps.
path to YAML configuration file.
whether to remove the code and state query
parameters from the URL after successful authentication. Defaults to TRUE.
Other arguments passed on to shiny::shinyApp().
You can also use a diferent configuration file by setting the
auth0_config_file option with:
options(auth0_config_file = "path/to/file.yaml").
Sometimes, using auth0 to develop and test apps can be frustrating,
because every time the app is started, auth0 requires the user to log-in.
To avoid this problem, one can run options(auth0_disable = TRUE) to
disable auth0 temporarily.